# Generated by Django 5.2.6 on 2025-10-01 02:20

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_he", "0009_rename_education_educationtype_and_more"),
    ]

    operations = [
        migrations.DeleteModel(
            name="HistoricalEducationType",
        ),
    ]
