{% load i18n %}
<H5><B><span style="color:orange">Interviewer to read</span></B></H5>
<p>
  {% translate "I would now like to know if you own any" %} <B>{% translate "land or other property" %}</B> – {% translate "and the approximate value (amount). I know this is sensitive information and will not share this with any persons outside of the survey team" %}. <B><U>{% translate "There is no need to give details or show me any of the items" %}.</U></B>
</P>
