{% load i18n %}
<H5><B><span style="color:orange">Interviewer to read</span></B></H5>
<P>We want to learn about the household and we use these questions
to get an understanding of wealth and opportunities in the community.</P>
<p>Now, I will ask about <b>income for the household</b> from paid work or
other sources.</p><p>I know it may be difficult to calculate those figures,
but please do try to give amounts as accurately as possible. Remember
that <b>all information will be kept strictly confidential</b>. This
information is important to assess overall health and well-being of
people in your household, compared to other similar households.</p><p>
I am now going to read you a list of possible sources of income.
Thinking over the last 12 months, can you tell me what the average
earnings of the household have been per week or per month or per year?
Please tell me whichever time period that is easier for you.</p>
