{% load i18n %}
<H5><B><span style="color:darkorange">Note to interviewer</span></B></H5>
If the PATIENT is the head of household, skip to the bottom of this form and click SAVE or SAVE NEXT, otherwise continue.
<H5><B><span style="color:orange">Interviewer to read</span></B></H5>
<p>By <B>HEAD OF THE HOUSEHOLD</B> we mean the <u>main decision maker</u> in the HOUSEHOLD. The HEAD can be either male or female. If two people are equal decision-makers, take the older person</p>",
