# Generated by Django 5.2.6 on 2025-09-30 23:23

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("edc_he", "0008_healtheconomics_alter_education_extra_value_and_more"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.RenameModel(
            old_name="Education",
            new_name="EducationType",
        ),
        migrations.RenameModel(
            old_name="HistoricalEducation",
            new_name="HistoricalEducationType",
        ),
        migrations.DeleteModel(
            name="HealthEconomics",
        ),
        migrations.AlterModelOptions(
            name="educationtype",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Education type",
                "verbose_name_plural": "Education types",
            },
        ),
        migrations.AlterModelOptions(
            name="historicaleducationtype",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Education type",
                "verbose_name_plural": "historical Education types",
            },
        ),
        migrations.RenameIndex(
            model_name="educationtype",
            new_name="edc_he_educ_display_73adba_idx",
            old_name="edc_he_educ_display_66a8e9_idx",
        ),
    ]
