{% load i18n %}
<H5><B><span style="color:orange">{%  translate "Interviewer to read" %}</span></B></H5>
<p>{%  translate "Now, I will ask about the total current debt/loans for the household. I know it may be difficult to calculate this, but please do try to give amounts as accurately as possible. Remember that all information will be kept strictly confidential" %}. <B> {%  translate "It is not possible to offer any help for your debts through this project" %}</B>, {%  translate "but this information will contribute to research and is important to assess the overall health and well-being of people in your household, compared to other similar households" %}.</p>
