from .assets_model_admin_mixin import HealthEconomicsAssetsModelAdminMixin
from .household_head_model_admin_mixin import (
    HealthEconomicsHouseholdHeadModelAdminMixin,
)
from .income_model_admin_mixin import HealthEconomicsIncomeModelAdminMixin
from .patient_model_admin_mixin import HealthEconomicsPatientModelAdminMixin
from .property_model_admin_mixin import HealthEconomicsPropertyModelAdminMixin
