# Generated by Django 4.2.7 on 2023-12-04 22:19

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "edc_he",
            "0006_alter_education_options_alter_employmenttype_options_and_more",
        ),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="education",
            name="edc_he_educ_name_64c0c9_idx",
        ),
        migrations.RemoveIndex(
            model_name="employmenttype",
            name="edc_he_empl_name_b36be4_idx",
        ),
        migrations.RemoveIndex(
            model_name="ethnicities",
            name="edc_he_ethn_name_e7e98d_idx",
        ),
        migrations.RemoveIndex(
            model_name="insurancetypes",
            name="edc_he_insu_name_f9caac_idx",
        ),
        migrations.RemoveIndex(
            model_name="nationalities",
            name="edc_he_nati_name_cba5f6_idx",
        ),
        migrations.RemoveIndex(
            model_name="religions",
            name="edc_he_reli_name_b2fcb4_idx",
        ),
    ]
