{% load i18n %}
<H5><B><span style="color:orange">Interviewer to read</span></B></H5>
<p>By a <B>HOUSEHOLD</B> {{ household_description }}.</P>
<P>By a <B>HOUSEHOLD_MEMBER</B> {{ household_member_description }}.
</P><P><B>Note:</B> {{ household_description_extra }}.</p>
